summaryrefslogtreecommitdiffstats
path: root/third_party/python/taskcluster_taskgraph/taskgraph/loader/default.py
diff options
context:
space:
mode:
Diffstat (limited to 'third_party/python/taskcluster_taskgraph/taskgraph/loader/default.py')
-rw-r--r--third_party/python/taskcluster_taskgraph/taskgraph/loader/default.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/third_party/python/taskcluster_taskgraph/taskgraph/loader/default.py b/third_party/python/taskcluster_taskgraph/taskgraph/loader/default.py
index 5b2c258917..f060a1d92d 100644
--- a/third_party/python/taskcluster_taskgraph/taskgraph/loader/default.py
+++ b/third_party/python/taskcluster_taskgraph/taskgraph/loader/default.py
@@ -11,7 +11,7 @@ logger = logging.getLogger(__name__)
DEFAULT_TRANSFORMS = [
- "taskgraph.transforms.job:transforms",
+ "taskgraph.transforms.run:transforms",
"taskgraph.transforms.task:transforms",
]
@@ -20,7 +20,7 @@ def loader(kind, path, config, params, loaded_tasks):
"""
This default loader builds on the `transform` loader by providing sensible
default transforms that the majority of simple tasks will need.
Specifically, `job` and `task` transforms will be appended to the end of the
list of transforms in the kind being loaded.
"""
transform_refs = config.setdefault("transforms", [])
@@ -20,7 +20,7 @@ def loader(kind, path, config, params, loaded_tasks):
This default loader builds on the `transform` loader by providing sensible
default transforms that the majority of simple tasks will need.
- Specifically, `job` and `task` transforms will be appended to the end of the
+ Specifically, `run` and `task` transforms will be appended to the end of the
list of transforms in the kind being loaded.
"""